@@ -40,16 +40,22 @@
 #include "Logger.h"
 #include "MainWindow.h"
 #include "Updater.h"
+#include "Widgets/InOutPanel.h"
 #include "Widgets/LanguageSelectionWidget.h"
 #include "Widgets/ProgressInfoWindow.h"
 #include "gmic.h"
+#ifdef _IS_MACOS_
+#include <libgen.h>
+#include <mach-o/dyld.h>
+#include <stdlib.h>
+#endif
 
 namespace GmicQt
 {
-const InputMode DefaultInputMode = Active;
-const OutputMode DefaultOutputMode = InPlace;
+InputMode DefaultInputMode = Active;
+OutputMode DefaultOutputMode = InPlace;
+PreviewMode DefaultPreviewMode = FirstOutput;
 const OutputMessageMode DefaultOutputMessageMode = Quiet;
-
 const QString & gmicVersionString()
 {
   static QString value = QString("%1.%2.%3").arg(gmic_version / 100).arg((gmic_version / 10) % 10).arg(gmic_version % 10);
@@ -57,31 +63,71 @@ const QString & gmicVersionString()
 }
 } // namespace GmicQt
 
+namespace
+{
+bool pluginProcessingValidAndAccepted = false;
+}
+
 int launchPlugin()
 {
   TIMING;
   int dummy_argc = 1;
   char dummy_app_name[] = GMIC_QT_APPLICATION_NAME;
-  char * dummy_argv[1] = {dummy_app_name};
 
 #ifdef _IS_WINDOWS_
   SetErrorMode(SEM_FAILCRITICALERRORS | SEM_NOGPFAULTERRORBOX | SEM_NOOPENFILEERRORBOX);
 #endif
 
+  char * fullexname = nullptr;
+#ifdef _IS_MACOS_
+  {
+    char exname[2048] = {0};
+    // get the path where the executable is stored
+    uint32_t size = sizeof(exname);
+    if (_NSGetExecutablePath(exname, &size) == 0) {
+      printf("executable path is %s\n", exname);
+      fullexname = realpath(exname, nullptr);
+      printf("full executable name is %s\n", fullexname);
+      if (fullexname) {
+        char * fullpath = dirname(fullexname);
+        printf("full executable path is %s\n", fullpath);
+        if (fullpath) {
+          char pluginpath[2048] = {0};
+          strncpy(pluginpath, fullpath, 2047);
+          strncat(pluginpath, "/GMIC/plugins/:", 2047);
+          char * envpath = getenv("QT_PLUGIN_PATH");
+          if (envpath) {
+            strncat(pluginpath, envpath, 2047);
+          }
+          printf("plugins path is %s\n", pluginpath);
+          setenv("QT_PLUGIN_PATH", pluginpath, 1);
+        }
+      }
+    } else {
+      fprintf(stderr, "buffer too small; need size %u\n", size);
+    }
+    setenv("QT_DEBUG_PLUGINS", "1", 1);
+  }
+#endif
+  if (!fullexname) {
+    fullexname = dummy_app_name;
+  }
+  char * dummy_argv[1] = {fullexname};
+
   QApplication app(dummy_argc, dummy_argv);
-  app.setWindowIcon(QIcon(":resources/gmic_hat.png"));
+  QApplication::setWindowIcon(QIcon(":resources/gmic_hat.png"));
   QCoreApplication::setOrganizationName(GMIC_QT_ORGANISATION_NAME);
   QCoreApplication::setOrganizationDomain(GMIC_QT_ORGANISATION_DOMAIN);
   QCoreApplication::setApplicationName(GMIC_QT_APPLICATION_NAME);
   QCoreApplication::setAttribute(Qt::AA_DontUseNativeMenuBar);
-  DialogSettings::loadSettings();
+  DialogSettings::loadSettings(GmicQt::GuiApplication);
 
   // Translate according to current locale or configured language
   QString lang = LanguageSelectionWidget::configuredTranslator();
   if (!lang.isEmpty() && (lang != "en")) {
-    QTranslator * translator = new QTranslator(&app);
+    auto translator = new QTranslator(&app);
     translator->load(QString(":/translations/%1.qm").arg(lang));
-    app.installTranslator(translator);
+    QApplication::installTranslator(translator);
   }
   TIMING;
   MainWindow mainWindow;
@@ -92,7 +138,9 @@ int launchPlugin()
     mainWindow.show();
   }
   TIMING;
-  return app.exec();
+  int status = QApplication::exec();
+  pluginProcessingValidAndAccepted = mainWindow.isAccepted();
+  return status;
 }
 
 int launchPluginHeadlessUsingLastParameters()
@@ -100,34 +148,37 @@ int launchPluginHeadlessUsingLastParameters()
   int dummy_argc = 1;
   char dummy_app_name[] = GMIC_QT_APPLICATION_NAME;
   char * dummy_argv[1] = {dummy_app_name};
+
 #ifdef _IS_WINDOWS_
   SetErrorMode(SEM_FAILCRITICALERRORS | SEM_NOGPFAULTERRORBOX | SEM_NOOPENFILEERRORBOX);
 #endif
   QApplication app(dummy_argc, dummy_argv);
-  app.setWindowIcon(QIcon(":resources/gmic_hat.png"));
+  QApplication::setWindowIcon(QIcon(":resources/gmic_hat.png"));
   QCoreApplication::setOrganizationName(GMIC_QT_ORGANISATION_NAME);
   QCoreApplication::setOrganizationDomain(GMIC_QT_ORGANISATION_DOMAIN);
   QCoreApplication::setApplicationName(GMIC_QT_APPLICATION_NAME);
   QCoreApplication::setAttribute(Qt::AA_DontUseNativeMenuBar);
 
-  DialogSettings::loadSettings();
+  DialogSettings::loadSettings(GmicQt::GuiApplication);
   Logger::setMode(DialogSettings::outputMessageMode());
   // Translate according to current locale or configured language
   QString lang = LanguageSelectionWidget::configuredTranslator();
   if (!lang.isEmpty() && (lang != "en")) {
-    QTranslator * translator = new QTranslator(&app);
+    auto translator = new QTranslator(&app);
     translator->load(QString(":/translations/%1.qm").arg(lang));
-    app.installTranslator(translator);
+    QCoreApplication::installTranslator(translator);
   }
 
   HeadlessProcessor processor;
   ProgressInfoWindow progressWindow(&processor);
   if (processor.command().isEmpty()) {
+    pluginProcessingValidAndAccepted = false;
     return 0;
-  } else {
-    processor.startProcessing();
-    return app.exec();
   }
+  processor.startProcessing();
+  int status = QApplication::exec();
+  pluginProcessingValidAndAccepted = processor.processingCompletedProperly();
+  return status;
 }
 
 int launchPluginHeadless(const char * command, GmicQt::InputMode input, GmicQt::OutputMode output)
@@ -135,6 +186,7 @@ int launchPluginHeadless(const char * command, GmicQt::InputMode input, GmicQt::
   int dummy_argc = 1;
   char dummy_app_name[] = GMIC_QT_APPLICATION_NAME;
   char * dummy_argv[1] = {dummy_app_name};
+
 #ifdef _IS_WINDOWS_
   SetErrorMode(SEM_FAILCRITICALERRORS | SEM_NOGPFAULTERRORBOX | SEM_NOOPENFILEERRORBOX);
 #endif
@@ -144,7 +196,7 @@ int launchPluginHeadless(const char * command, GmicQt::InputMode input, GmicQt::
   QCoreApplication::setApplicationName(GMIC_QT_APPLICATION_NAME);
   QCoreApplication::setAttribute(Qt::AA_DontUseNativeMenuBar);
 
-  DialogSettings::loadSettings();
+  DialogSettings::loadSettings(GmicQt::NonGuiApplication);
   Logger::setMode(DialogSettings::outputMessageMode());
 
   HeadlessProcessor headlessProcessor(&app, command, input, output);
@@ -153,5 +205,27 @@ int launchPluginHeadless(const char * command, GmicQt::InputMode input, GmicQt::
   idle.setSingleShot(true);
   QObject::connect(&idle, SIGNAL(timeout()), &headlessProcessor, SLOT(startProcessing()));
   idle.start();
-  return app.exec();
+  int status = QCoreApplication::exec();
+  pluginProcessingValidAndAccepted = headlessProcessor.processingCompletedProperly();
+  return status;
+}
+
+void disableOutputMode(GmicQt::OutputMode mode)
+{
+  InOutPanel::disableOutputMode(mode);
+}
+
+void disableInputMode(GmicQt::InputMode mode)
+{
+  InOutPanel::disableInputMode(mode);
+}
+
+void disablePreviewMode(GmicQt::PreviewMode mode)
+{
+  InOutPanel::disablePreviewMode(mode);
+}
+
+bool pluginDialogWasAccepted()
+{
+  return pluginProcessingValidAndAccepted;
 }
